Currently punch hole and collapse range fallocate operation are not
allowed on append only file. This should be case for zero range as well.
Fix it.

Signed-off-by: Lukas Czerner <[email protected]>
---
 fs/open.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/fs/open.c b/fs/open.c
index 631aea81..7882ff5 100644
--- a/fs/open.c
+++ b/fs/open.c
@@ -254,10 +254,11 @@ int do_fallocate(struct file *file, int mode, loff_t 
offset, loff_t len)
                return -EBADF;
 
        /*
         * It's not possible to punch hole or perform collapse range
         * on append only file
         */
-       if (mode & (FALLOC_FL_PUNCH_HOLE | FALLOC_FL_COLLAPSE_RANGE)
+       if (mode & (FALLOC_FL_PUNCH_HOLE | FALLOC_FL_COLLAPSE_RANGE |
+                   FALLOC_FL_ZERO_RANGE)
            && IS_APPEND(inode))
                return -EPERM;
 
@@ -254,10 +254,11 @@ int do_fallocate(struct file *file, int mode, loff_t 
 
        /*
-        * It's not possible to punch hole or perform collapse range
-        * on append only file
+        * It's not possible to punch hole, perform collapse range
+        * or zero range on append only file
         */
-- 
1.8.3.1

--
To unsubscribe from this list: send the line "unsubscribe ceph-devel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to